@@ -18,18 +18,14 @@
 # under the License.
 
 import urllib
+
 from gstack import app
-from flask import jsonify, Response
-
-
-@app.errorhandler(404)
-def not_found(e):
-    return Response('Not Found', status=404, mimetype='text/html')
+from gstack import helpers
 
 
 @app.errorhandler(401)
 def unauthorized(e):
-    res = jsonify({
+    res = {
         'error': {
             'errors': [
                 {
@@ -43,14 +39,13 @@ def unauthorized(e):
         },
         'code': 401,
         'message': 'Login Required',
-    })
+    }
 
-    res.status_code = 401
-    return res
+    return helpers.create_errored_response(res, 401)
 
 
 def resource_not_found(func_url):
-    res = jsonify({
+    res = {
         'error': {
             'errors': [
                 {
@@ -62,16 +57,16 @@ def resource_not_found(func_url):
             'code': 404,
             'message': 'The resource \'' + urllib.unquote_plus(func_url) + '\' was not found'
         }
-    })
-    res.status_code = 404
-    return res
+    }
+
+    return helpers.create_errored_response(res, 404)
 
 
 def no_results_found(scope):
     return ({
         "warning": {
             "code": "NO_RESULTS_ON_PAGE",
-            "message": "There are no results for scope" + scope + " on this page.",
+            "message": "There are no results for scope " + scope + " on this page.",
             "data": [{
                 "key": "scope",
                 "value": scope
