@@ -21,5 +21,10 @@ from gstack import db
 
 
 class Client(db.Model):
+    __tablename__ = 'client'
     client_id = db.Column(db.String(100), primary_key=True, unique=True)
     client_secret = db.Column(db.String(100), unique=True)
+
+    def __init__(self, client_id, client_secret):
+        self.client_id = client_id
+        self.client_secret = client_secret
